@@ -11,7 +11,7 @@ use Carp;
 use Exporter qw{ import };
 use Test::More 0.88;	# Because of done_testing();
 
-our $VERSION = '0.000_01';
+our $VERSION = '0.000_02';
 
 our @EXPORT = qw{
     is_au_au
@@ -22,7 +22,10 @@ our @EXPORT = qw{
     washington_dc
 };
 
-use constant 'Astro::Coord::ECI::VSOP87D::DEBUG' => $ENV{VSOP87D_DEBUG};
+{
+    package Astro::Coord::ECI::VSOP87D;
+    use constant DEBUG => $ENV{VSOP87D_DEBUG};
+}
 
 sub is_au_au ($$$$) {
     my ( $got, $want, $dp, $title ) = @_;
